# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/gcs_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as src_dot_ray_dot_protobuf_dot_common__pb2
from . import gcs_pb2 as src_dot_ray_dot_protobuf_dot_gcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/gcs_service.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\"src/ray/protobuf/gcs_service.proto\x12\x07ray.rpc\x1a\x1dsrc/ray/protobuf/common.proto\x1a\x1asrc/ray/protobuf/gcs.proto\"9\n\tGcsStatus\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\":\n\rAddJobRequest\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.ray.rpc.JobTableDataR\x04\x64\x61ta\"9\n\x0b\x41\x64\x64JobReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"/\n\x16MarkJobFinishedRequest\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\"B\n\x14MarkJobFinishedReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x16\n\x14GetAllJobInfoRequest\"{\n\x12GetAllJobInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x39\n\rjob_info_list\x18\x02 \x03(\x0b\x32\x15.ray.rpc.JobTableDataR\x0bjobInfoList\"D\n\x13GetActorInfoRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x82\x01\n\x11GetActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\".\n\x18GetNamedActorInfoRequest\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x87\x01\n\x16GetNamedActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"\x18\n\x16GetAllActorInfoRequest\"\x85\x01\n\x14GetAllActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x03(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"]\n\x18RegisterActorInfoRequest\x12\x41\n\x10\x61\x63tor_table_data\x18\x01 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"D\n\x16RegisterActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"v\n\x16UpdateActorInfoRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"B\n\x14UpdateActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"H\n\x13RegisterNodeRequest\x12\x31\n\tnode_info\x18\x01 \x01(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x08nodeInfo\"?\n\x11RegisterNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"0\n\x15UnregisterNodeRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"A\n\x13UnregisterNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x17\n\x15GetAllNodeInfoRequest\"}\n\x13GetAllNodeInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12:\n\x0enode_info_list\x18\x02 \x03(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x0cnodeInfoList\"S\n\x16ReportHeartbeatRequest\x12\x39\n\theartbeat\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.HeartbeatTableDataR\theartbeat\"B\n\x14ReportHeartbeatReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x18\n\x16GetAllHeartbeatRequest\"\x8b\x01\n\x14GetAllHeartbeatReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12G\n\x0eheartbeat_data\x18\x02 \x01(\x0b\x32 .ray.rpc.HeartbeatBatchTableDataR\rheartbeatData\"R\n\x1aReportResourceUsageRequest\x12\x34\n\tresources\x18\x01 \x01(\x0b\x32\x16.ray.rpc.ResourcesDataR\tresources\"F\n\x18ReportResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x1c\n\x1aGetAllResourceUsageRequest\"\x85\x01\n\x18GetAllResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12=\n\x0eresources_list\x18\x02 \x03(\x0b\x32\x16.ray.rpc.ResourcesDataR\rresourcesList\".\n\x13GetResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"\xe2\x01\n\x11GetResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12G\n\tresources\x18\x02 \x03(\x0b\x32).ray.rpc.GetResourcesReply.ResourcesEntryR\tresources\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"\xd9\x01\n\x16UpdateResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12L\n\tresources\x18\x02 \x03(\x0b\x32..ray.rpc.UpdateResourcesRequest.ResourcesEntryR\tresources\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"B\n\x14UpdateResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"_\n\x16\x44\x65leteResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12,\n\x12resource_name_list\x18\x02 \x03(\tR\x10resourceNameList\"B\n\x14\x44\x65leteResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"I\n\x18SetInternalConfigRequest\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x15.ray.rpc.StoredConfigR\x06\x63onfig\"D\n\x16SetInternalConfigReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x1a\n\x18GetInternalConfigRequest\"s\n\x16GetInternalConfigReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x15.ray.rpc.StoredConfigR\x06\x63onfig\"!\n\x1fGetAllAvailableResourcesRequest\"\x8f\x01\n\x1dGetAllAvailableResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x42\n\x0eresources_list\x18\x02 \x03(\x0b\x32\x1b.ray.rpc.AvailableResourcesR\rresourcesList\"8\n\x19GetObjectLocationsRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\"\x87\x01\n\x17GetObjectLocationsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12@\n\rlocation_info\x18\x02 \x01(\x0b\x32\x1b.ray.rpc.ObjectLocationInfoR\x0clocationInfo\"\x1e\n\x1cGetAllObjectLocationsRequest\"\xa0\x01\n\x1aGetAllObjectLocationsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12V\n\x19object_location_info_list\x18\x02 \x03(\x0b\x32\x1b.ray.rpc.ObjectLocationInfoR\x16objectLocationInfoList\"q\n\x18\x41\x64\x64ObjectLocationRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\"D\n\x16\x41\x64\x64ObjectLocationReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"F\n\x18\x41\x64\x64ObjectSpilledUrlReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"S\n\x1bRemoveObjectLocationRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\"G\n\x19RemoveObjectLocationReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"E\n\x0e\x41\x64\x64TaskRequest\x12\x33\n\ttask_data\x18\x01 \x01(\x0b\x32\x16.ray.rpc.TaskTableDataR\x08taskData\":\n\x0c\x41\x64\x64TaskReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\")\n\x0eGetTaskRequest\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\"o\n\x0cGetTaskReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x33\n\ttask_data\x18\x02 \x01(\x0b\x32\x16.ray.rpc.TaskTableDataR\x08taskData\"6\n\x12\x44\x65leteTasksRequest\x12 \n\x0ctask_id_list\x18\x01 \x03(\x0cR\ntaskIdList\">\n\x10\x44\x65leteTasksReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"U\n\x13\x41\x64\x64TaskLeaseRequest\x12>\n\x0ftask_lease_data\x18\x01 \x01(\x0b\x32\x16.ray.rpc.TaskLeaseDataR\rtaskLeaseData\"?\n\x11\x41\x64\x64TaskLeaseReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\".\n\x13GetTaskLeaseRequest\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\"\x7f\n\x11GetTaskLeaseReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12>\n\x0ftask_lease_data\x18\x02 \x01(\x0b\x32\x16.ray.rpc.TaskLeaseDataR\rtaskLeaseData\"t\n AttemptTaskReconstructionRequest\x12P\n\x13task_reconstruction\x18\x01 \x01(\x0b\x32\x1f.ray.rpc.TaskReconstructionDataR\x12taskReconstruction\"L\n\x1e\x41ttemptTaskReconstructionReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"U\n\x15\x41\x64\x64ProfileDataRequest\x12<\n\x0cprofile_data\x18\x01 \x01(\x0b\x32\x19.ray.rpc.ProfileTableDataR\x0bprofileData\"A\n\x13\x41\x64\x64ProfileDataReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x1a\n\x18GetAllProfileInfoRequest\"\x8b\x01\n\x16GetAllProfileInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x45\n\x11profile_info_list\x18\x02 \x03(\x0b\x32\x19.ray.rpc.ProfileTableDataR\x0fprofileInfoList\"]\n\x1aReportWorkerFailureRequest\x12?\n\x0eworker_failure\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\rworkerFailure\"F\n\x18ReportWorkerFailureReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"3\n\x14GetWorkerInfoRequest\x12\x1b\n\tworker_id\x18\x01 \x01(\x0cR\x08workerId\"\x86\x01\n\x12GetWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\"\x19\n\x17GetAllWorkerInfoRequest\"\x89\x01\n\x15GetAllWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x03(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\"Q\n\x14\x41\x64\x64WorkerInfoRequest\x12\x39\n\x0bworker_data\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\nworkerData\"@\n\x12\x41\x64\x64WorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"D\n\x12\x43reateActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\">\n\x10\x43reateActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"F\n\x14RegisterActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\"@\n\x12RegisterActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"l\n\x1b\x43reatePlacementGroupRequest\x12M\n\x14placement_group_spec\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.PlacementGroupSpecR\x12placementGroupSpec\"G\n\x19\x43reatePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"K\n\x1bRemovePlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"G\n\x19RemovePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"H\n\x18GetPlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"\xa3\x01\n\x16GetPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x01(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"\x1d\n\x1bGetAllPlacementGroupRequest\"\xa6\x01\n\x19GetAllPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x03(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"S\n#WaitPlacementGroupUntilReadyRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"O\n!WaitPlacementGroupUntilReadyReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status*C\n\x15GcsServiceFailureType\x12\x12\n\x0eRPC_DISCONNECT\x10\x00\x12\x16\n\x12GCS_SERVER_RESTART\x10\x01\x32\xeb\x01\n\x11JobInfoGcsService\x12\x36\n\x06\x41\x64\x64Job\x12\x16.ray.rpc.AddJobRequest\x1a\x14.ray.rpc.AddJobReply\x12Q\n\x0fMarkJobFinished\x12\x1f.ray.rpc.MarkJobFinishedRequest\x1a\x1d.ray.rpc.MarkJobFinishedReply\x12K\n\rGetAllJobInfo\x12\x1d.ray.rpc.GetAllJobInfoRequest\x1a\x1b.ray.rpc.GetAllJobInfoReply2\xcb\x04\n\x13\x41\x63torInfoGcsService\x12K\n\rRegisterActor\x12\x1d.ray.rpc.RegisterActorRequest\x1a\x1b.ray.rpc.RegisterActorReply\x12\x45\n\x0b\x43reateActor\x12\x1b.ray.rpc.CreateActorRequest\x1a\x19.ray.rpc.CreateActorReply\x12H\n\x0cGetActorInfo\x12\x1c.ray.rpc.GetActorInfoRequest\x1a\x1a.ray.rpc.GetActorInfoReply\x12W\n\x11GetNamedActorInfo\x12!.ray.rpc.GetNamedActorInfoRequest\x1a\x1f.ray.rpc.GetNamedActorInfoReply\x12Q\n\x0fGetAllActorInfo\x12\x1f.ray.rpc.GetAllActorInfoRequest\x1a\x1d.ray.rpc.GetAllActorInfoReply\x12W\n\x11RegisterActorInfo\x12!.ray.rpc.RegisterActorInfoRequest\x1a\x1f.ray.rpc.RegisterActorInfoReply\x12Q\n\x0fUpdateActorInfo\x12\x1f.ray.rpc.UpdateActorInfoRequest\x1a\x1d.ray.rpc.UpdateActorInfoReply2\xf2\x08\n\x12NodeInfoGcsService\x12H\n\x0cRegisterNode\x12\x1c.ray.rpc.RegisterNodeRequest\x1a\x1a.ray.rpc.RegisterNodeReply\x12N\n\x0eUnregisterNode\x12\x1e.ray.rpc.UnregisterNodeRequest\x1a\x1c.ray.rpc.UnregisterNodeReply\x12N\n\x0eGetAllNodeInfo\x12\x1e.ray.rpc.GetAllNodeInfoRequest\x1a\x1c.ray.rpc.GetAllNodeInfoReply\x12Q\n\x0fReportHeartbeat\x12\x1f.ray.rpc.ReportHeartbeatRequest\x1a\x1d.ray.rpc.ReportHeartbeatReply\x12Q\n\x0fGetAllHeartbeat\x12\x1f.ray.rpc.GetAllHeartbeatRequest\x1a\x1d.ray.rpc.GetAllHeartbeatReply\x12]\n\x13ReportResourceUsage\x12#.ray.rpc.ReportResourceUsageRequest\x1a!.ray.rpc.ReportResourceUsageReply\x12]\n\x13GetAllResourceUsage\x12#.ray.rpc.GetAllResourceUsageRequest\x1a!.ray.rpc.GetAllResourceUsageReply\x12H\n\x0cGetResources\x12\x1c.ray.rpc.GetResourcesRequest\x1a\x1a.ray.rpc.GetResourcesReply\x12Q\n\x0fUpdateResources\x12\x1f.ray.rpc.UpdateResourcesRequest\x1a\x1d.ray.rpc.UpdateResourcesReply\x12Q\n\x0f\x44\x65leteResources\x12\x1f.ray.rpc.DeleteResourcesRequest\x1a\x1d.ray.rpc.DeleteResourcesReply\x12W\n\x11SetInternalConfig\x12!.ray.rpc.SetInternalConfigRequest\x1a\x1f.ray.rpc.SetInternalConfigReply\x12W\n\x11GetInternalConfig\x12!.ray.rpc.GetInternalConfigRequest\x1a\x1f.ray.rpc.GetInternalConfigReply\x12l\n\x18GetAllAvailableResources\x12(.ray.rpc.GetAllAvailableResourcesRequest\x1a&.ray.rpc.GetAllAvailableResourcesReply2\x92\x03\n\x14ObjectInfoGcsService\x12Z\n\x12GetObjectLocations\x12\".ray.rpc.GetObjectLocationsRequest\x1a .ray.rpc.GetObjectLocationsReply\x12\x63\n\x15GetAllObjectLocations\x12%.ray.rpc.GetAllObjectLocationsRequest\x1a#.ray.rpc.GetAllObjectLocationsReply\x12W\n\x11\x41\x64\x64ObjectLocation\x12!.ray.rpc.AddObjectLocationRequest\x1a\x1f.ray.rpc.AddObjectLocationReply\x12`\n\x14RemoveObjectLocation\x12$.ray.rpc.RemoveObjectLocationRequest\x1a\".ray.rpc.RemoveObjectLocationReply2\xd6\x03\n\x12TaskInfoGcsService\x12\x39\n\x07\x41\x64\x64Task\x12\x17.ray.rpc.AddTaskRequest\x1a\x15.ray.rpc.AddTaskReply\x12\x39\n\x07GetTask\x12\x17.ray.rpc.GetTaskRequest\x1a\x15.ray.rpc.GetTaskReply\x12\x45\n\x0b\x44\x65leteTasks\x12\x1b.ray.rpc.DeleteTasksRequest\x1a\x19.ray.rpc.DeleteTasksReply\x12H\n\x0c\x41\x64\x64TaskLease\x12\x1c.ray.rpc.AddTaskLeaseRequest\x1a\x1a.ray.rpc.AddTaskLeaseReply\x12H\n\x0cGetTaskLease\x12\x1c.ray.rpc.GetTaskLeaseRequest\x1a\x1a.ray.rpc.GetTaskLeaseReply\x12o\n\x19\x41ttemptTaskReconstruction\x12).ray.rpc.AttemptTaskReconstructionRequest\x1a\'.ray.rpc.AttemptTaskReconstructionReply2\xba\x01\n\x0fStatsGcsService\x12N\n\x0e\x41\x64\x64ProfileData\x12\x1e.ray.rpc.AddProfileDataRequest\x1a\x1c.ray.rpc.AddProfileDataReply\x12W\n\x11GetAllProfileInfo\x12!.ray.rpc.GetAllProfileInfoRequest\x1a\x1f.ray.rpc.GetAllProfileInfoReply2\xe5\x02\n\x14WorkerInfoGcsService\x12]\n\x13ReportWorkerFailure\x12#.ray.rpc.ReportWorkerFailureRequest\x1a!.ray.rpc.ReportWorkerFailureReply\x12K\n\rGetWorkerInfo\x12\x1d.ray.rpc.GetWorkerInfoRequest\x1a\x1b.ray.rpc.GetWorkerInfoReply\x12T\n\x10GetAllWorkerInfo\x12 .ray.rpc.GetAllWorkerInfoRequest\x1a\x1e.ray.rpc.GetAllWorkerInfoReply\x12K\n\rAddWorkerInfo\x12\x1d.ray.rpc.AddWorkerInfoRequest\x1a\x1b.ray.rpc.AddWorkerInfoReply2\x97\x04\n\x1cPlacementGroupInfoGcsService\x12`\n\x14\x43reatePlacementGroup\x12$.ray.rpc.CreatePlacementGroupRequest\x1a\".ray.rpc.CreatePlacementGroupReply\x12`\n\x14RemovePlacementGroup\x12$.ray.rpc.RemovePlacementGroupRequest\x1a\".ray.rpc.RemovePlacementGroupReply\x12W\n\x11GetPlacementGroup\x12!.ray.rpc.GetPlacementGroupRequest\x1a\x1f.ray.rpc.GetPlacementGroupReply\x12`\n\x14GetAllPlacementGroup\x12$.ray.rpc.GetAllPlacementGroupRequest\x1a\".ray.rpc.GetAllPlacementGroupReply\x12x\n\x1cWaitPlacementGroupUntilReady\x12,.ray.rpc.WaitPlacementGroupUntilReadyRequest\x1a*.ray.rpc.WaitPlacementGroupUntilReadyReplyb\x06proto3')
  ,
  dependencies=[src_dot_ray_dot_protobuf_dot_common__pb2.DESCRIPTOR,src_dot_ray_dot_protobuf_dot_gcs__pb2.DESCRIPTOR,])

_GCSSERVICEFAILURETYPE = _descriptor.EnumDescriptor(
  name='GcsServiceFailureType',
  full_name='ray.rpc.GcsServiceFailureType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RPC_DISCONNECT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCS_SERVER_RESTART', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7652,
  serialized_end=7719,
)
_sym_db.RegisterEnumDescriptor(_GCSSERVICEFAILURETYPE)

GcsServiceFailureType = enum_type_wrapper.EnumTypeWrapper(_GCSSERVICEFAILURETYPE)
RPC_DISCONNECT = 0
GCS_SERVER_RESTART = 1



_GCSSTATUS = _descriptor.Descriptor(
  name='GcsStatus',
  full_name='ray.rpc.GcsStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ray.rpc.GcsStatus.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='ray.rpc.GcsStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=163,
)


_ADDJOBREQUEST = _descriptor.Descriptor(
  name='AddJobRequest',
  full_name='ray.rpc.AddJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.AddJobRequest.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=223,
)


_ADDJOBREPLY = _descriptor.Descriptor(
  name='AddJobReply',
  full_name='ray.rpc.AddJobReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddJobReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=282,
)


_MARKJOBFINISHEDREQUEST = _descriptor.Descriptor(
  name='MarkJobFinishedRequest',
  full_name='ray.rpc.MarkJobFinishedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.MarkJobFinishedRequest.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=331,
)


_MARKJOBFINISHEDREPLY = _descriptor.Descriptor(
  name='MarkJobFinishedReply',
  full_name='ray.rpc.MarkJobFinishedReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.MarkJobFinishedReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=399,
)


_GETALLJOBINFOREQUEST = _descriptor.Descriptor(
  name='GetAllJobInfoRequest',
  full_name='ray.rpc.GetAllJobInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=423,
)


_GETALLJOBINFOREPLY = _descriptor.Descriptor(
  name='GetAllJobInfoReply',
  full_name='ray.rpc.GetAllJobInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllJobInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_info_list', full_name='ray.rpc.GetAllJobInfoReply.job_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobInfoList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=548,
)


_GETACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetActorInfoRequest',
  full_name='ray.rpc.GetActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.GetActorInfoRequest.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.GetActorInfoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=618,
)


_GETACTORINFOREPLY = _descriptor.Descriptor(
  name='GetActorInfoReply',
  full_name='ray.rpc.GetActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=751,
)


_GETNAMEDACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetNamedActorInfoRequest',
  full_name='ray.rpc.GetNamedActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.GetNamedActorInfoRequest.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=799,
)


_GETNAMEDACTORINFOREPLY = _descriptor.Descriptor(
  name='GetNamedActorInfoReply',
  full_name='ray.rpc.GetNamedActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetNamedActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetNamedActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=937,
)


_GETALLACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetAllActorInfoRequest',
  full_name='ray.rpc.GetAllActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=963,
)


_GETALLACTORINFOREPLY = _descriptor.Descriptor(
  name='GetAllActorInfoReply',
  full_name='ray.rpc.GetAllActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetAllActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1099,
)


_REGISTERACTORINFOREQUEST = _descriptor.Descriptor(
  name='RegisterActorInfoRequest',
  full_name='ray.rpc.RegisterActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.RegisterActorInfoRequest.actor_table_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1194,
)


_REGISTERACTORINFOREPLY = _descriptor.Descriptor(
  name='RegisterActorInfoReply',
  full_name='ray.rpc.RegisterActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RegisterActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1264,
)


_UPDATEACTORINFOREQUEST = _descriptor.Descriptor(
  name='UpdateActorInfoRequest',
  full_name='ray.rpc.UpdateActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.UpdateActorInfoRequest.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.UpdateActorInfoRequest.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1384,
)


_UPDATEACTORINFOREPLY = _descriptor.Descriptor(
  name='UpdateActorInfoReply',
  full_name='ray.rpc.UpdateActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.UpdateActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1452,
)


_REGISTERNODEREQUEST = _descriptor.Descriptor(
  name='RegisterNodeRequest',
  full_name='ray.rpc.RegisterNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_info', full_name='ray.rpc.RegisterNodeRequest.node_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeInfo', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1454,
  serialized_end=1526,
)


_REGISTERNODEREPLY = _descriptor.Descriptor(
  name='RegisterNodeReply',
  full_name='ray.rpc.RegisterNodeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RegisterNodeReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1528,
  serialized_end=1591,
)


_UNREGISTERNODEREQUEST = _descriptor.Descriptor(
  name='UnregisterNodeRequest',
  full_name='ray.rpc.UnregisterNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.UnregisterNodeRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1593,
  serialized_end=1641,
)


_UNREGISTERNODEREPLY = _descriptor.Descriptor(
  name='UnregisterNodeReply',
  full_name='ray.rpc.UnregisterNodeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.UnregisterNodeReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1643,
  serialized_end=1708,
)


_GETALLNODEINFOREQUEST = _descriptor.Descriptor(
  name='GetAllNodeInfoRequest',
  full_name='ray.rpc.GetAllNodeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1733,
)


_GETALLNODEINFOREPLY = _descriptor.Descriptor(
  name='GetAllNodeInfoReply',
  full_name='ray.rpc.GetAllNodeInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllNodeInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_info_list', full_name='ray.rpc.GetAllNodeInfoReply.node_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeInfoList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1735,
  serialized_end=1860,
)


_REPORTHEARTBEATREQUEST = _descriptor.Descriptor(
  name='ReportHeartbeatRequest',
  full_name='ray.rpc.ReportHeartbeatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heartbeat', full_name='ray.rpc.ReportHeartbeatRequest.heartbeat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heartbeat', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1862,
  serialized_end=1945,
)


_REPORTHEARTBEATREPLY = _descriptor.Descriptor(
  name='ReportHeartbeatReply',
  full_name='ray.rpc.ReportHeartbeatReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportHeartbeatReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1947,
  serialized_end=2013,
)


_GETALLHEARTBEATREQUEST = _descriptor.Descriptor(
  name='GetAllHeartbeatRequest',
  full_name='ray.rpc.GetAllHeartbeatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2015,
  serialized_end=2039,
)


_GETALLHEARTBEATREPLY = _descriptor.Descriptor(
  name='GetAllHeartbeatReply',
  full_name='ray.rpc.GetAllHeartbeatReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllHeartbeatReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heartbeat_data', full_name='ray.rpc.GetAllHeartbeatReply.heartbeat_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heartbeatData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2042,
  serialized_end=2181,
)


_REPORTRESOURCEUSAGEREQUEST = _descriptor.Descriptor(
  name='ReportResourceUsageRequest',
  full_name='ray.rpc.ReportResourceUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.ReportResourceUsageRequest.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2183,
  serialized_end=2265,
)


_REPORTRESOURCEUSAGEREPLY = _descriptor.Descriptor(
  name='ReportResourceUsageReply',
  full_name='ray.rpc.ReportResourceUsageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportResourceUsageReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2267,
  serialized_end=2337,
)


_GETALLRESOURCEUSAGEREQUEST = _descriptor.Descriptor(
  name='GetAllResourceUsageRequest',
  full_name='ray.rpc.GetAllResourceUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2339,
  serialized_end=2367,
)


_GETALLRESOURCEUSAGEREPLY = _descriptor.Descriptor(
  name='GetAllResourceUsageReply',
  full_name='ray.rpc.GetAllResourceUsageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllResourceUsageReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_list', full_name='ray.rpc.GetAllResourceUsageReply.resources_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2503,
)


_GETRESOURCESREQUEST = _descriptor.Descriptor(
  name='GetResourcesRequest',
  full_name='ray.rpc.GetResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.GetResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2505,
  serialized_end=2551,
)


_GETRESOURCESREPLY_RESOURCESENTRY = _descriptor.Descriptor(
  name='ResourcesEntry',
  full_name='ray.rpc.GetResourcesReply.ResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.GetResourcesReply.ResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.GetResourcesReply.ResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2780,
)

_GETRESOURCESREPLY = _descriptor.Descriptor(
  name='GetResourcesReply',
  full_name='ray.rpc.GetResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.GetResourcesReply.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETRESOURCESREPLY_RESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2554,
  serialized_end=2780,
)


_UPDATERESOURCESREQUEST_RESOURCESENTRY = _descriptor.Descriptor(
  name='ResourcesEntry',
  full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2780,
)

_UPDATERESOURCESREQUEST = _descriptor.Descriptor(
  name='UpdateResourcesRequest',
  full_name='ray.rpc.UpdateResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.UpdateResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.UpdateResourcesRequest.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATERESOURCESREQUEST_RESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2783,
  serialized_end=3000,
)


_UPDATERESOURCESREPLY = _descriptor.Descriptor(
  name='UpdateResourcesReply',
  full_name='ray.rpc.UpdateResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.UpdateResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3002,
  serialized_end=3068,
)


_DELETERESOURCESREQUEST = _descriptor.Descriptor(
  name='DeleteResourcesRequest',
  full_name='ray.rpc.DeleteResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.DeleteResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_name_list', full_name='ray.rpc.DeleteResourcesRequest.resource_name_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceNameList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3070,
  serialized_end=3165,
)


_DELETERESOURCESREPLY = _descriptor.Descriptor(
  name='DeleteResourcesReply',
  full_name='ray.rpc.DeleteResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.DeleteResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3167,
  serialized_end=3233,
)


_SETINTERNALCONFIGREQUEST = _descriptor.Descriptor(
  name='SetInternalConfigRequest',
  full_name='ray.rpc.SetInternalConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.SetInternalConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3235,
  serialized_end=3308,
)


_SETINTERNALCONFIGREPLY = _descriptor.Descriptor(
  name='SetInternalConfigReply',
  full_name='ray.rpc.SetInternalConfigReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.SetInternalConfigReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3378,
)


_GETINTERNALCONFIGREQUEST = _descriptor.Descriptor(
  name='GetInternalConfigRequest',
  full_name='ray.rpc.GetInternalConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3380,
  serialized_end=3406,
)


_GETINTERNALCONFIGREPLY = _descriptor.Descriptor(
  name='GetInternalConfigReply',
  full_name='ray.rpc.GetInternalConfigReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetInternalConfigReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.GetInternalConfigReply.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3408,
  serialized_end=3523,
)


_GETALLAVAILABLERESOURCESREQUEST = _descriptor.Descriptor(
  name='GetAllAvailableResourcesRequest',
  full_name='ray.rpc.GetAllAvailableResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3525,
  serialized_end=3558,
)


_GETALLAVAILABLERESOURCESREPLY = _descriptor.Descriptor(
  name='GetAllAvailableResourcesReply',
  full_name='ray.rpc.GetAllAvailableResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllAvailableResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_list', full_name='ray.rpc.GetAllAvailableResourcesReply.resources_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3561,
  serialized_end=3704,
)


_GETOBJECTLOCATIONSREQUEST = _descriptor.Descriptor(
  name='GetObjectLocationsRequest',
  full_name='ray.rpc.GetObjectLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.GetObjectLocationsRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3706,
  serialized_end=3762,
)


_GETOBJECTLOCATIONSREPLY = _descriptor.Descriptor(
  name='GetObjectLocationsReply',
  full_name='ray.rpc.GetObjectLocationsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetObjectLocationsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_info', full_name='ray.rpc.GetObjectLocationsReply.location_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='locationInfo', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3765,
  serialized_end=3900,
)


_GETALLOBJECTLOCATIONSREQUEST = _descriptor.Descriptor(
  name='GetAllObjectLocationsRequest',
  full_name='ray.rpc.GetAllObjectLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3902,
  serialized_end=3932,
)


_GETALLOBJECTLOCATIONSREPLY = _descriptor.Descriptor(
  name='GetAllObjectLocationsReply',
  full_name='ray.rpc.GetAllObjectLocationsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllObjectLocationsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_location_info_list', full_name='ray.rpc.GetAllObjectLocationsReply.object_location_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectLocationInfoList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3935,
  serialized_end=4095,
)


_ADDOBJECTLOCATIONREQUEST = _descriptor.Descriptor(
  name='AddObjectLocationRequest',
  full_name='ray.rpc.AddObjectLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.AddObjectLocationRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.AddObjectLocationRequest.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.AddObjectLocationRequest.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4097,
  serialized_end=4210,
)


_ADDOBJECTLOCATIONREPLY = _descriptor.Descriptor(
  name='AddObjectLocationReply',
  full_name='ray.rpc.AddObjectLocationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddObjectLocationReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4212,
  serialized_end=4280,
)


_ADDOBJECTSPILLEDURLREPLY = _descriptor.Descriptor(
  name='AddObjectSpilledUrlReply',
  full_name='ray.rpc.AddObjectSpilledUrlReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddObjectSpilledUrlReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4282,
  serialized_end=4352,
)


_REMOVEOBJECTLOCATIONREQUEST = _descriptor.Descriptor(
  name='RemoveObjectLocationRequest',
  full_name='ray.rpc.RemoveObjectLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.RemoveObjectLocationRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.RemoveObjectLocationRequest.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4354,
  serialized_end=4437,
)


_REMOVEOBJECTLOCATIONREPLY = _descriptor.Descriptor(
  name='RemoveObjectLocationReply',
  full_name='ray.rpc.RemoveObjectLocationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RemoveObjectLocationReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4439,
  serialized_end=4510,
)


_ADDTASKREQUEST = _descriptor.Descriptor(
  name='AddTaskRequest',
  full_name='ray.rpc.AddTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_data', full_name='ray.rpc.AddTaskRequest.task_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4512,
  serialized_end=4581,
)


_ADDTASKREPLY = _descriptor.Descriptor(
  name='AddTaskReply',
  full_name='ray.rpc.AddTaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddTaskReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4583,
  serialized_end=4641,
)


_GETTASKREQUEST = _descriptor.Descriptor(
  name='GetTaskRequest',
  full_name='ray.rpc.GetTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.GetTaskRequest.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4643,
  serialized_end=4684,
)


_GETTASKREPLY = _descriptor.Descriptor(
  name='GetTaskReply',
  full_name='ray.rpc.GetTaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetTaskReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_data', full_name='ray.rpc.GetTaskReply.task_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4686,
  serialized_end=4797,
)


_DELETETASKSREQUEST = _descriptor.Descriptor(
  name='DeleteTasksRequest',
  full_name='ray.rpc.DeleteTasksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id_list', full_name='ray.rpc.DeleteTasksRequest.task_id_list', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskIdList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4799,
  serialized_end=4853,
)


_DELETETASKSREPLY = _descriptor.Descriptor(
  name='DeleteTasksReply',
  full_name='ray.rpc.DeleteTasksReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.DeleteTasksReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4855,
  serialized_end=4917,
)


_ADDTASKLEASEREQUEST = _descriptor.Descriptor(
  name='AddTaskLeaseRequest',
  full_name='ray.rpc.AddTaskLeaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_lease_data', full_name='ray.rpc.AddTaskLeaseRequest.task_lease_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskLeaseData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4919,
  serialized_end=5004,
)


_ADDTASKLEASEREPLY = _descriptor.Descriptor(
  name='AddTaskLeaseReply',
  full_name='ray.rpc.AddTaskLeaseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddTaskLeaseReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5006,
  serialized_end=5069,
)


_GETTASKLEASEREQUEST = _descriptor.Descriptor(
  name='GetTaskLeaseRequest',
  full_name='ray.rpc.GetTaskLeaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.GetTaskLeaseRequest.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5071,
  serialized_end=5117,
)


_GETTASKLEASEREPLY = _descriptor.Descriptor(
  name='GetTaskLeaseReply',
  full_name='ray.rpc.GetTaskLeaseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetTaskLeaseReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_lease_data', full_name='ray.rpc.GetTaskLeaseReply.task_lease_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskLeaseData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5119,
  serialized_end=5246,
)


_ATTEMPTTASKRECONSTRUCTIONREQUEST = _descriptor.Descriptor(
  name='AttemptTaskReconstructionRequest',
  full_name='ray.rpc.AttemptTaskReconstructionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_reconstruction', full_name='ray.rpc.AttemptTaskReconstructionRequest.task_reconstruction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskReconstruction', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5248,
  serialized_end=5364,
)


_ATTEMPTTASKRECONSTRUCTIONREPLY = _descriptor.Descriptor(
  name='AttemptTaskReconstructionReply',
  full_name='ray.rpc.AttemptTaskReconstructionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AttemptTaskReconstructionReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5366,
  serialized_end=5442,
)


_ADDPROFILEDATAREQUEST = _descriptor.Descriptor(
  name='AddProfileDataRequest',
  full_name='ray.rpc.AddProfileDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_data', full_name='ray.rpc.AddProfileDataRequest.profile_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5444,
  serialized_end=5529,
)


_ADDPROFILEDATAREPLY = _descriptor.Descriptor(
  name='AddProfileDataReply',
  full_name='ray.rpc.AddProfileDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddProfileDataReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5531,
  serialized_end=5596,
)


_GETALLPROFILEINFOREQUEST = _descriptor.Descriptor(
  name='GetAllProfileInfoRequest',
  full_name='ray.rpc.GetAllProfileInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5598,
  serialized_end=5624,
)


_GETALLPROFILEINFOREPLY = _descriptor.Descriptor(
  name='GetAllProfileInfoReply',
  full_name='ray.rpc.GetAllProfileInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllProfileInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_info_list', full_name='ray.rpc.GetAllProfileInfoReply.profile_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileInfoList', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5627,
  serialized_end=5766,
)


_REPORTWORKERFAILUREREQUEST = _descriptor.Descriptor(
  name='ReportWorkerFailureRequest',
  full_name='ray.rpc.ReportWorkerFailureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_failure', full_name='ray.rpc.ReportWorkerFailureRequest.worker_failure', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerFailure', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5768,
  serialized_end=5861,
)


_REPORTWORKERFAILUREREPLY = _descriptor.Descriptor(
  name='ReportWorkerFailureReply',
  full_name='ray.rpc.ReportWorkerFailureReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportWorkerFailureReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5863,
  serialized_end=5933,
)


_GETWORKERINFOREQUEST = _descriptor.Descriptor(
  name='GetWorkerInfoRequest',
  full_name='ray.rpc.GetWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='ray.rpc.GetWorkerInfoRequest.worker_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5935,
  serialized_end=5986,
)


_GETWORKERINFOREPLY = _descriptor.Descriptor(
  name='GetWorkerInfoReply',
  full_name='ray.rpc.GetWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_table_data', full_name='ray.rpc.GetWorkerInfoReply.worker_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5989,
  serialized_end=6123,
)


_GETALLWORKERINFOREQUEST = _descriptor.Descriptor(
  name='GetAllWorkerInfoRequest',
  full_name='ray.rpc.GetAllWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6125,
  serialized_end=6150,
)


_GETALLWORKERINFOREPLY = _descriptor.Descriptor(
  name='GetAllWorkerInfoReply',
  full_name='ray.rpc.GetAllWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker_table_data', full_name='ray.rpc.GetAllWorkerInfoReply.worker_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6153,
  serialized_end=6290,
)


_ADDWORKERINFOREQUEST = _descriptor.Descriptor(
  name='AddWorkerInfoRequest',
  full_name='ray.rpc.AddWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_data', full_name='ray.rpc.AddWorkerInfoRequest.worker_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6292,
  serialized_end=6373,
)


_ADDWORKERINFOREPLY = _descriptor.Descriptor(
  name='AddWorkerInfoReply',
  full_name='ray.rpc.AddWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6375,
  serialized_end=6439,
)


_CREATEACTORREQUEST = _descriptor.Descriptor(
  name='CreateActorRequest',
  full_name='ray.rpc.CreateActorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.CreateActorRequest.task_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6441,
  serialized_end=6509,
)


_CREATEACTORREPLY = _descriptor.Descriptor(
  name='CreateActorReply',
  full_name='ray.rpc.CreateActorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.CreateActorReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6511,
  serialized_end=6573,
)


_REGISTERACTORREQUEST = _descriptor.Descriptor(
  name='RegisterActorRequest',
  full_name='ray.rpc.RegisterActorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.RegisterActorRequest.task_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6575,
  serialized_end=6645,
)


_REGISTERACTORREPLY = _descriptor.Descriptor(
  name='RegisterActorReply',
  full_name='ray.rpc.RegisterActorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RegisterActorReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6647,
  serialized_end=6711,
)


_CREATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='CreatePlacementGroupRequest',
  full_name='ray.rpc.CreatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_spec', full_name='ray.rpc.CreatePlacementGroupRequest.placement_group_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupSpec', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6713,
  serialized_end=6821,
)


_CREATEPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='CreatePlacementGroupReply',
  full_name='ray.rpc.CreatePlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.CreatePlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6823,
  serialized_end=6894,
)


_REMOVEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='RemovePlacementGroupRequest',
  full_name='ray.rpc.RemovePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.RemovePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6896,
  serialized_end=6971,
)


_REMOVEPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='RemovePlacementGroupReply',
  full_name='ray.rpc.RemovePlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RemovePlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6973,
  serialized_end=7044,
)


_GETPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetPlacementGroupRequest',
  full_name='ray.rpc.GetPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.GetPlacementGroupRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7046,
  serialized_end=7118,
)


_GETPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='GetPlacementGroupReply',
  full_name='ray.rpc.GetPlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetPlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_group_table_data', full_name='ray.rpc.GetPlacementGroupReply.placement_group_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7121,
  serialized_end=7284,
)


_GETALLPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetAllPlacementGroupRequest',
  full_name='ray.rpc.GetAllPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7286,
  serialized_end=7315,
)


_GETALLPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='GetAllPlacementGroupReply',
  full_name='ray.rpc.GetAllPlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllPlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_group_table_data', full_name='ray.rpc.GetAllPlacementGroupReply.placement_group_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupTableData', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7318,
  serialized_end=7484,
)


_WAITPLACEMENTGROUPUNTILREADYREQUEST = _descriptor.Descriptor(
  name='WaitPlacementGroupUntilReadyRequest',
  full_name='ray.rpc.WaitPlacementGroupUntilReadyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.WaitPlacementGroupUntilReadyRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7486,
  serialized_end=7569,
)


_WAITPLACEMENTGROUPUNTILREADYREPLY = _descriptor.Descriptor(
  name='WaitPlacementGroupUntilReadyReply',
  full_name='ray.rpc.WaitPlacementGroupUntilReadyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.WaitPlacementGroupUntilReadyReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7571,
  serialized_end=7650,
)

_ADDJOBREQUEST.fields_by_name['data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._JOBTABLEDATA
_ADDJOBREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_MARKJOBFINISHEDREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLJOBINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLJOBINFOREPLY.fields_by_name['job_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._JOBTABLEDATA
_GETACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_GETNAMEDACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETNAMEDACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_GETALLACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_REGISTERACTORINFOREQUEST.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_REGISTERACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_UPDATEACTORINFOREQUEST.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_UPDATEACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REGISTERNODEREQUEST.fields_by_name['node_info'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._GCSNODEINFO
_REGISTERNODEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_UNREGISTERNODEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLNODEINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLNODEINFOREPLY.fields_by_name['node_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._GCSNODEINFO
_REPORTHEARTBEATREQUEST.fields_by_name['heartbeat'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._HEARTBEATTABLEDATA
_REPORTHEARTBEATREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLHEARTBEATREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLHEARTBEATREPLY.fields_by_name['heartbeat_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._HEARTBEATBATCHTABLEDATA
_REPORTRESOURCEUSAGEREQUEST.fields_by_name['resources'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCESDATA
_REPORTRESOURCEUSAGEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLRESOURCEUSAGEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLRESOURCEUSAGEREPLY.fields_by_name['resources_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCESDATA
_GETRESOURCESREPLY_RESOURCESENTRY.fields_by_name['value'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCETABLEDATA
_GETRESOURCESREPLY_RESOURCESENTRY.containing_type = _GETRESOURCESREPLY
_GETRESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETRESOURCESREPLY.fields_by_name['resources'].message_type = _GETRESOURCESREPLY_RESOURCESENTRY
_UPDATERESOURCESREQUEST_RESOURCESENTRY.fields_by_name['value'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCETABLEDATA
_UPDATERESOURCESREQUEST_RESOURCESENTRY.containing_type = _UPDATERESOURCESREQUEST
_UPDATERESOURCESREQUEST.fields_by_name['resources'].message_type = _UPDATERESOURCESREQUEST_RESOURCESENTRY
_UPDATERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_DELETERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_SETINTERNALCONFIGREQUEST.fields_by_name['config'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._STOREDCONFIG
_SETINTERNALCONFIGREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETINTERNALCONFIGREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETINTERNALCONFIGREPLY.fields_by_name['config'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._STOREDCONFIG
_GETALLAVAILABLERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLAVAILABLERESOURCESREPLY.fields_by_name['resources_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._AVAILABLERESOURCES
_GETOBJECTLOCATIONSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETOBJECTLOCATIONSREPLY.fields_by_name['location_info'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._OBJECTLOCATIONINFO
_GETALLOBJECTLOCATIONSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLOBJECTLOCATIONSREPLY.fields_by_name['object_location_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._OBJECTLOCATIONINFO
_ADDOBJECTLOCATIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDOBJECTSPILLEDURLREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REMOVEOBJECTLOCATIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDTASKREQUEST.fields_by_name['task_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKTABLEDATA
_ADDTASKREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKREPLY.fields_by_name['task_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKTABLEDATA
_DELETETASKSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDTASKLEASEREQUEST.fields_by_name['task_lease_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKLEASEDATA
_ADDTASKLEASEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKLEASEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKLEASEREPLY.fields_by_name['task_lease_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKLEASEDATA
_ATTEMPTTASKRECONSTRUCTIONREQUEST.fields_by_name['task_reconstruction'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKRECONSTRUCTIONDATA
_ATTEMPTTASKRECONSTRUCTIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDPROFILEDATAREQUEST.fields_by_name['profile_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PROFILETABLEDATA
_ADDPROFILEDATAREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPROFILEINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPROFILEINFOREPLY.fields_by_name['profile_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PROFILETABLEDATA
_REPORTWORKERFAILUREREQUEST.fields_by_name['worker_failure'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_REPORTWORKERFAILUREREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETWORKERINFOREPLY.fields_by_name['worker_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_GETALLWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLWORKERINFOREPLY.fields_by_name['worker_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_ADDWORKERINFOREQUEST.fields_by_name['worker_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_ADDWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_CREATEACTORREQUEST.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_CREATEACTORREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REGISTERACTORREQUEST.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_REGISTERACTORREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['placement_group_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._PLACEMENTGROUPSPEC
_CREATEPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REMOVEPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETPLACEMENTGROUPREPLY.fields_by_name['placement_group_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PLACEMENTGROUPTABLEDATA
_GETALLPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPLACEMENTGROUPREPLY.fields_by_name['placement_group_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PLACEMENTGROUPTABLEDATA
_WAITPLACEMENTGROUPUNTILREADYREPLY.fields_by_name['status'].message_type = _GCSSTATUS
DESCRIPTOR.message_types_by_name['GcsStatus'] = _GCSSTATUS
DESCRIPTOR.message_types_by_name['AddJobRequest'] = _ADDJOBREQUEST
DESCRIPTOR.message_types_by_name['AddJobReply'] = _ADDJOBREPLY
DESCRIPTOR.message_types_by_name['MarkJobFinishedRequest'] = _MARKJOBFINISHEDREQUEST
DESCRIPTOR.message_types_by_name['MarkJobFinishedReply'] = _MARKJOBFINISHEDREPLY
DESCRIPTOR.message_types_by_name['GetAllJobInfoRequest'] = _GETALLJOBINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllJobInfoReply'] = _GETALLJOBINFOREPLY
DESCRIPTOR.message_types_by_name['GetActorInfoRequest'] = _GETACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetActorInfoReply'] = _GETACTORINFOREPLY
DESCRIPTOR.message_types_by_name['GetNamedActorInfoRequest'] = _GETNAMEDACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetNamedActorInfoReply'] = _GETNAMEDACTORINFOREPLY
DESCRIPTOR.message_types_by_name['GetAllActorInfoRequest'] = _GETALLACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllActorInfoReply'] = _GETALLACTORINFOREPLY
DESCRIPTOR.message_types_by_name['RegisterActorInfoRequest'] = _REGISTERACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['RegisterActorInfoReply'] = _REGISTERACTORINFOREPLY
DESCRIPTOR.message_types_by_name['UpdateActorInfoRequest'] = _UPDATEACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['UpdateActorInfoReply'] = _UPDATEACTORINFOREPLY
DESCRIPTOR.message_types_by_name['RegisterNodeRequest'] = _REGISTERNODEREQUEST
DESCRIPTOR.message_types_by_name['RegisterNodeReply'] = _REGISTERNODEREPLY
DESCRIPTOR.message_types_by_name['UnregisterNodeRequest'] = _UNREGISTERNODEREQUEST
DESCRIPTOR.message_types_by_name['UnregisterNodeReply'] = _UNREGISTERNODEREPLY
DESCRIPTOR.message_types_by_name['GetAllNodeInfoRequest'] = _GETALLNODEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllNodeInfoReply'] = _GETALLNODEINFOREPLY
DESCRIPTOR.message_types_by_name['ReportHeartbeatRequest'] = _REPORTHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['ReportHeartbeatReply'] = _REPORTHEARTBEATREPLY
DESCRIPTOR.message_types_by_name['GetAllHeartbeatRequest'] = _GETALLHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['GetAllHeartbeatReply'] = _GETALLHEARTBEATREPLY
DESCRIPTOR.message_types_by_name['ReportResourceUsageRequest'] = _REPORTRESOURCEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['ReportResourceUsageReply'] = _REPORTRESOURCEUSAGEREPLY
DESCRIPTOR.message_types_by_name['GetAllResourceUsageRequest'] = _GETALLRESOURCEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['GetAllResourceUsageReply'] = _GETALLRESOURCEUSAGEREPLY
DESCRIPTOR.message_types_by_name['GetResourcesRequest'] = _GETRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetResourcesReply'] = _GETRESOURCESREPLY
DESCRIPTOR.message_types_by_name['UpdateResourcesRequest'] = _UPDATERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['UpdateResourcesReply'] = _UPDATERESOURCESREPLY
DESCRIPTOR.message_types_by_name['DeleteResourcesRequest'] = _DELETERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['DeleteResourcesReply'] = _DELETERESOURCESREPLY
DESCRIPTOR.message_types_by_name['SetInternalConfigRequest'] = _SETINTERNALCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetInternalConfigReply'] = _SETINTERNALCONFIGREPLY
DESCRIPTOR.message_types_by_name['GetInternalConfigRequest'] = _GETINTERNALCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetInternalConfigReply'] = _GETINTERNALCONFIGREPLY
DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesRequest'] = _GETALLAVAILABLERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesReply'] = _GETALLAVAILABLERESOURCESREPLY
DESCRIPTOR.message_types_by_name['GetObjectLocationsRequest'] = _GETOBJECTLOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetObjectLocationsReply'] = _GETOBJECTLOCATIONSREPLY
DESCRIPTOR.message_types_by_name['GetAllObjectLocationsRequest'] = _GETALLOBJECTLOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetAllObjectLocationsReply'] = _GETALLOBJECTLOCATIONSREPLY
DESCRIPTOR.message_types_by_name['AddObjectLocationRequest'] = _ADDOBJECTLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['AddObjectLocationReply'] = _ADDOBJECTLOCATIONREPLY
DESCRIPTOR.message_types_by_name['AddObjectSpilledUrlReply'] = _ADDOBJECTSPILLEDURLREPLY
DESCRIPTOR.message_types_by_name['RemoveObjectLocationRequest'] = _REMOVEOBJECTLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['RemoveObjectLocationReply'] = _REMOVEOBJECTLOCATIONREPLY
DESCRIPTOR.message_types_by_name['AddTaskRequest'] = _ADDTASKREQUEST
DESCRIPTOR.message_types_by_name['AddTaskReply'] = _ADDTASKREPLY
DESCRIPTOR.message_types_by_name['GetTaskRequest'] = _GETTASKREQUEST
DESCRIPTOR.message_types_by_name['GetTaskReply'] = _GETTASKREPLY
DESCRIPTOR.message_types_by_name['DeleteTasksRequest'] = _DELETETASKSREQUEST
DESCRIPTOR.message_types_by_name['DeleteTasksReply'] = _DELETETASKSREPLY
DESCRIPTOR.message_types_by_name['AddTaskLeaseRequest'] = _ADDTASKLEASEREQUEST
DESCRIPTOR.message_types_by_name['AddTaskLeaseReply'] = _ADDTASKLEASEREPLY
DESCRIPTOR.message_types_by_name['GetTaskLeaseRequest'] = _GETTASKLEASEREQUEST
DESCRIPTOR.message_types_by_name['GetTaskLeaseReply'] = _GETTASKLEASEREPLY
DESCRIPTOR.message_types_by_name['AttemptTaskReconstructionRequest'] = _ATTEMPTTASKRECONSTRUCTIONREQUEST
DESCRIPTOR.message_types_by_name['AttemptTaskReconstructionReply'] = _ATTEMPTTASKRECONSTRUCTIONREPLY
DESCRIPTOR.message_types_by_name['AddProfileDataRequest'] = _ADDPROFILEDATAREQUEST
DESCRIPTOR.message_types_by_name['AddProfileDataReply'] = _ADDPROFILEDATAREPLY
DESCRIPTOR.message_types_by_name['GetAllProfileInfoRequest'] = _GETALLPROFILEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllProfileInfoReply'] = _GETALLPROFILEINFOREPLY
DESCRIPTOR.message_types_by_name['ReportWorkerFailureRequest'] = _REPORTWORKERFAILUREREQUEST
DESCRIPTOR.message_types_by_name['ReportWorkerFailureReply'] = _REPORTWORKERFAILUREREPLY
DESCRIPTOR.message_types_by_name['GetWorkerInfoRequest'] = _GETWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetWorkerInfoReply'] = _GETWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['GetAllWorkerInfoRequest'] = _GETALLWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllWorkerInfoReply'] = _GETALLWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['AddWorkerInfoRequest'] = _ADDWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['AddWorkerInfoReply'] = _ADDWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['CreateActorRequest'] = _CREATEACTORREQUEST
DESCRIPTOR.message_types_by_name['CreateActorReply'] = _CREATEACTORREPLY
DESCRIPTOR.message_types_by_name['RegisterActorRequest'] = _REGISTERACTORREQUEST
DESCRIPTOR.message_types_by_name['RegisterActorReply'] = _REGISTERACTORREPLY
DESCRIPTOR.message_types_by_name['CreatePlacementGroupRequest'] = _CREATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreatePlacementGroupReply'] = _CREATEPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['RemovePlacementGroupRequest'] = _REMOVEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['RemovePlacementGroupReply'] = _REMOVEPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['GetPlacementGroupRequest'] = _GETPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetPlacementGroupReply'] = _GETPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['GetAllPlacementGroupRequest'] = _GETALLPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetAllPlacementGroupReply'] = _GETALLPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyRequest'] = _WAITPLACEMENTGROUPUNTILREADYREQUEST
DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyReply'] = _WAITPLACEMENTGROUPUNTILREADYREPLY
DESCRIPTOR.enum_types_by_name['GcsServiceFailureType'] = _GCSSERVICEFAILURETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GcsStatus = _reflection.GeneratedProtocolMessageType('GcsStatus', (_message.Message,), {
  'DESCRIPTOR' : _GCSSTATUS,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsStatus)
  })
_sym_db.RegisterMessage(GcsStatus)

AddJobRequest = _reflection.GeneratedProtocolMessageType('AddJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobRequest)
  })
_sym_db.RegisterMessage(AddJobRequest)

AddJobReply = _reflection.GeneratedProtocolMessageType('AddJobReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobReply)
  })
_sym_db.RegisterMessage(AddJobReply)

MarkJobFinishedRequest = _reflection.GeneratedProtocolMessageType('MarkJobFinishedRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedRequest)
  })
_sym_db.RegisterMessage(MarkJobFinishedRequest)

MarkJobFinishedReply = _reflection.GeneratedProtocolMessageType('MarkJobFinishedReply', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedReply)
  })
_sym_db.RegisterMessage(MarkJobFinishedReply)

GetAllJobInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllJobInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoRequest)
  })
_sym_db.RegisterMessage(GetAllJobInfoRequest)

GetAllJobInfoReply = _reflection.GeneratedProtocolMessageType('GetAllJobInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoReply)
  })
_sym_db.RegisterMessage(GetAllJobInfoReply)

GetActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoRequest)
  })
_sym_db.RegisterMessage(GetActorInfoRequest)

GetActorInfoReply = _reflection.GeneratedProtocolMessageType('GetActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoReply)
  })
_sym_db.RegisterMessage(GetActorInfoReply)

GetNamedActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoRequest)
  })
_sym_db.RegisterMessage(GetNamedActorInfoRequest)

GetNamedActorInfoReply = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoReply)
  })
_sym_db.RegisterMessage(GetNamedActorInfoReply)

GetAllActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoRequest)
  })
_sym_db.RegisterMessage(GetAllActorInfoRequest)

GetAllActorInfoReply = _reflection.GeneratedProtocolMessageType('GetAllActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoReply)
  })
_sym_db.RegisterMessage(GetAllActorInfoReply)

RegisterActorInfoRequest = _reflection.GeneratedProtocolMessageType('RegisterActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorInfoRequest)
  })
_sym_db.RegisterMessage(RegisterActorInfoRequest)

RegisterActorInfoReply = _reflection.GeneratedProtocolMessageType('RegisterActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorInfoReply)
  })
_sym_db.RegisterMessage(RegisterActorInfoReply)

UpdateActorInfoRequest = _reflection.GeneratedProtocolMessageType('UpdateActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateActorInfoRequest)
  })
_sym_db.RegisterMessage(UpdateActorInfoRequest)

UpdateActorInfoReply = _reflection.GeneratedProtocolMessageType('UpdateActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateActorInfoReply)
  })
_sym_db.RegisterMessage(UpdateActorInfoReply)

RegisterNodeRequest = _reflection.GeneratedProtocolMessageType('RegisterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeRequest)
  })
_sym_db.RegisterMessage(RegisterNodeRequest)

RegisterNodeReply = _reflection.GeneratedProtocolMessageType('RegisterNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeReply)
  })
_sym_db.RegisterMessage(RegisterNodeReply)

UnregisterNodeRequest = _reflection.GeneratedProtocolMessageType('UnregisterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UnregisterNodeRequest)
  })
_sym_db.RegisterMessage(UnregisterNodeRequest)

UnregisterNodeReply = _reflection.GeneratedProtocolMessageType('UnregisterNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UnregisterNodeReply)
  })
_sym_db.RegisterMessage(UnregisterNodeReply)

GetAllNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetAllNodeInfoRequest)

GetAllNodeInfoReply = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoReply)
  })
_sym_db.RegisterMessage(GetAllNodeInfoReply)

ReportHeartbeatRequest = _reflection.GeneratedProtocolMessageType('ReportHeartbeatRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTHEARTBEATREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportHeartbeatRequest)
  })
_sym_db.RegisterMessage(ReportHeartbeatRequest)

ReportHeartbeatReply = _reflection.GeneratedProtocolMessageType('ReportHeartbeatReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTHEARTBEATREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportHeartbeatReply)
  })
_sym_db.RegisterMessage(ReportHeartbeatReply)

GetAllHeartbeatRequest = _reflection.GeneratedProtocolMessageType('GetAllHeartbeatRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLHEARTBEATREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllHeartbeatRequest)
  })
_sym_db.RegisterMessage(GetAllHeartbeatRequest)

GetAllHeartbeatReply = _reflection.GeneratedProtocolMessageType('GetAllHeartbeatReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLHEARTBEATREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllHeartbeatReply)
  })
_sym_db.RegisterMessage(GetAllHeartbeatReply)

ReportResourceUsageRequest = _reflection.GeneratedProtocolMessageType('ReportResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageRequest)
  })
_sym_db.RegisterMessage(ReportResourceUsageRequest)

ReportResourceUsageReply = _reflection.GeneratedProtocolMessageType('ReportResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageReply)
  })
_sym_db.RegisterMessage(ReportResourceUsageReply)

GetAllResourceUsageRequest = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageRequest)
  })
_sym_db.RegisterMessage(GetAllResourceUsageRequest)

GetAllResourceUsageReply = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageReply)
  })
_sym_db.RegisterMessage(GetAllResourceUsageReply)

GetResourcesRequest = _reflection.GeneratedProtocolMessageType('GetResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesRequest)
  })
_sym_db.RegisterMessage(GetResourcesRequest)

GetResourcesReply = _reflection.GeneratedProtocolMessageType('GetResourcesReply', (_message.Message,), {

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETRESOURCESREPLY_RESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply.ResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _GETRESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply)
  })
_sym_db.RegisterMessage(GetResourcesReply)
_sym_db.RegisterMessage(GetResourcesReply.ResourcesEntry)

UpdateResourcesRequest = _reflection.GeneratedProtocolMessageType('UpdateResourcesRequest', (_message.Message,), {

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATERESOURCESREQUEST_RESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesRequest.ResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesRequest)
  })
_sym_db.RegisterMessage(UpdateResourcesRequest)
_sym_db.RegisterMessage(UpdateResourcesRequest.ResourcesEntry)

UpdateResourcesReply = _reflection.GeneratedProtocolMessageType('UpdateResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesReply)
  })
_sym_db.RegisterMessage(UpdateResourcesReply)

DeleteResourcesRequest = _reflection.GeneratedProtocolMessageType('DeleteResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteResourcesRequest)
  })
_sym_db.RegisterMessage(DeleteResourcesRequest)

DeleteResourcesReply = _reflection.GeneratedProtocolMessageType('DeleteResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteResourcesReply)
  })
_sym_db.RegisterMessage(DeleteResourcesReply)

SetInternalConfigRequest = _reflection.GeneratedProtocolMessageType('SetInternalConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERNALCONFIGREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.SetInternalConfigRequest)
  })
_sym_db.RegisterMessage(SetInternalConfigRequest)

SetInternalConfigReply = _reflection.GeneratedProtocolMessageType('SetInternalConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERNALCONFIGREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.SetInternalConfigReply)
  })
_sym_db.RegisterMessage(SetInternalConfigReply)

GetInternalConfigRequest = _reflection.GeneratedProtocolMessageType('GetInternalConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigRequest)
  })
_sym_db.RegisterMessage(GetInternalConfigRequest)

GetInternalConfigReply = _reflection.GeneratedProtocolMessageType('GetInternalConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigReply)
  })
_sym_db.RegisterMessage(GetInternalConfigReply)

GetAllAvailableResourcesRequest = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesRequest)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesRequest)

GetAllAvailableResourcesReply = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesReply)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesReply)

GetObjectLocationsRequest = _reflection.GeneratedProtocolMessageType('GetObjectLocationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTLOCATIONSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetObjectLocationsRequest)
  })
_sym_db.RegisterMessage(GetObjectLocationsRequest)

GetObjectLocationsReply = _reflection.GeneratedProtocolMessageType('GetObjectLocationsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTLOCATIONSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetObjectLocationsReply)
  })
_sym_db.RegisterMessage(GetObjectLocationsReply)

GetAllObjectLocationsRequest = _reflection.GeneratedProtocolMessageType('GetAllObjectLocationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLOBJECTLOCATIONSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllObjectLocationsRequest)
  })
_sym_db.RegisterMessage(GetAllObjectLocationsRequest)

GetAllObjectLocationsReply = _reflection.GeneratedProtocolMessageType('GetAllObjectLocationsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLOBJECTLOCATIONSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllObjectLocationsReply)
  })
_sym_db.RegisterMessage(GetAllObjectLocationsReply)

AddObjectLocationRequest = _reflection.GeneratedProtocolMessageType('AddObjectLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTLOCATIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectLocationRequest)
  })
_sym_db.RegisterMessage(AddObjectLocationRequest)

AddObjectLocationReply = _reflection.GeneratedProtocolMessageType('AddObjectLocationReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTLOCATIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectLocationReply)
  })
_sym_db.RegisterMessage(AddObjectLocationReply)

AddObjectSpilledUrlReply = _reflection.GeneratedProtocolMessageType('AddObjectSpilledUrlReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTSPILLEDURLREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectSpilledUrlReply)
  })
_sym_db.RegisterMessage(AddObjectSpilledUrlReply)

RemoveObjectLocationRequest = _reflection.GeneratedProtocolMessageType('RemoveObjectLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECTLOCATIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemoveObjectLocationRequest)
  })
_sym_db.RegisterMessage(RemoveObjectLocationRequest)

RemoveObjectLocationReply = _reflection.GeneratedProtocolMessageType('RemoveObjectLocationReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECTLOCATIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemoveObjectLocationReply)
  })
_sym_db.RegisterMessage(RemoveObjectLocationReply)

AddTaskRequest = _reflection.GeneratedProtocolMessageType('AddTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskRequest)
  })
_sym_db.RegisterMessage(AddTaskRequest)

AddTaskReply = _reflection.GeneratedProtocolMessageType('AddTaskReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskReply)
  })
_sym_db.RegisterMessage(AddTaskReply)

GetTaskRequest = _reflection.GeneratedProtocolMessageType('GetTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskRequest)
  })
_sym_db.RegisterMessage(GetTaskRequest)

GetTaskReply = _reflection.GeneratedProtocolMessageType('GetTaskReply', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskReply)
  })
_sym_db.RegisterMessage(GetTaskReply)

DeleteTasksRequest = _reflection.GeneratedProtocolMessageType('DeleteTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETASKSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteTasksRequest)
  })
_sym_db.RegisterMessage(DeleteTasksRequest)

DeleteTasksReply = _reflection.GeneratedProtocolMessageType('DeleteTasksReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETETASKSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteTasksReply)
  })
_sym_db.RegisterMessage(DeleteTasksReply)

AddTaskLeaseRequest = _reflection.GeneratedProtocolMessageType('AddTaskLeaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKLEASEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskLeaseRequest)
  })
_sym_db.RegisterMessage(AddTaskLeaseRequest)

AddTaskLeaseReply = _reflection.GeneratedProtocolMessageType('AddTaskLeaseReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKLEASEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskLeaseReply)
  })
_sym_db.RegisterMessage(AddTaskLeaseReply)

GetTaskLeaseRequest = _reflection.GeneratedProtocolMessageType('GetTaskLeaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKLEASEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskLeaseRequest)
  })
_sym_db.RegisterMessage(GetTaskLeaseRequest)

GetTaskLeaseReply = _reflection.GeneratedProtocolMessageType('GetTaskLeaseReply', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKLEASEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskLeaseReply)
  })
_sym_db.RegisterMessage(GetTaskLeaseReply)

AttemptTaskReconstructionRequest = _reflection.GeneratedProtocolMessageType('AttemptTaskReconstructionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTEMPTTASKRECONSTRUCTIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AttemptTaskReconstructionRequest)
  })
_sym_db.RegisterMessage(AttemptTaskReconstructionRequest)

AttemptTaskReconstructionReply = _reflection.GeneratedProtocolMessageType('AttemptTaskReconstructionReply', (_message.Message,), {
  'DESCRIPTOR' : _ATTEMPTTASKRECONSTRUCTIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AttemptTaskReconstructionReply)
  })
_sym_db.RegisterMessage(AttemptTaskReconstructionReply)

AddProfileDataRequest = _reflection.GeneratedProtocolMessageType('AddProfileDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROFILEDATAREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddProfileDataRequest)
  })
_sym_db.RegisterMessage(AddProfileDataRequest)

AddProfileDataReply = _reflection.GeneratedProtocolMessageType('AddProfileDataReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROFILEDATAREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddProfileDataReply)
  })
_sym_db.RegisterMessage(AddProfileDataReply)

GetAllProfileInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllProfileInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROFILEINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllProfileInfoRequest)
  })
_sym_db.RegisterMessage(GetAllProfileInfoRequest)

GetAllProfileInfoReply = _reflection.GeneratedProtocolMessageType('GetAllProfileInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROFILEINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllProfileInfoReply)
  })
_sym_db.RegisterMessage(GetAllProfileInfoReply)

ReportWorkerFailureRequest = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureRequest)
  })
_sym_db.RegisterMessage(ReportWorkerFailureRequest)

ReportWorkerFailureReply = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureReply)
  })
_sym_db.RegisterMessage(ReportWorkerFailureReply)

GetWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetWorkerInfoRequest)

GetWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetWorkerInfoReply)

GetAllWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoRequest)

GetAllWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoReply)

AddWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('AddWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoRequest)
  })
_sym_db.RegisterMessage(AddWorkerInfoRequest)

AddWorkerInfoReply = _reflection.GeneratedProtocolMessageType('AddWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoReply)
  })
_sym_db.RegisterMessage(AddWorkerInfoReply)

CreateActorRequest = _reflection.GeneratedProtocolMessageType('CreateActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorRequest)
  })
_sym_db.RegisterMessage(CreateActorRequest)

CreateActorReply = _reflection.GeneratedProtocolMessageType('CreateActorReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorReply)
  })
_sym_db.RegisterMessage(CreateActorReply)

RegisterActorRequest = _reflection.GeneratedProtocolMessageType('RegisterActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorRequest)
  })
_sym_db.RegisterMessage(RegisterActorRequest)

RegisterActorReply = _reflection.GeneratedProtocolMessageType('RegisterActorReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorReply)
  })
_sym_db.RegisterMessage(RegisterActorReply)

CreatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(CreatePlacementGroupRequest)

CreatePlacementGroupReply = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupReply)
  })
_sym_db.RegisterMessage(CreatePlacementGroupReply)

RemovePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupRequest)
  })
_sym_db.RegisterMessage(RemovePlacementGroupRequest)

RemovePlacementGroupReply = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupReply)
  })
_sym_db.RegisterMessage(RemovePlacementGroupReply)

GetPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetPlacementGroupRequest)

GetPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetPlacementGroupReply)

GetAllPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupRequest)

GetAllPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupReply)

WaitPlacementGroupUntilReadyRequest = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyRequest)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyRequest)

WaitPlacementGroupUntilReadyReply = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyReply', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyReply)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyReply)


_GETRESOURCESREPLY_RESOURCESENTRY._options = None
_UPDATERESOURCESREQUEST_RESOURCESENTRY._options = None

_JOBINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='JobInfoGcsService',
  full_name='ray.rpc.JobInfoGcsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7722,
  serialized_end=7957,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddJob',
    full_name='ray.rpc.JobInfoGcsService.AddJob',
    index=0,
    containing_service=None,
    input_type=_ADDJOBREQUEST,
    output_type=_ADDJOBREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarkJobFinished',
    full_name='ray.rpc.JobInfoGcsService.MarkJobFinished',
    index=1,
    containing_service=None,
    input_type=_MARKJOBFINISHEDREQUEST,
    output_type=_MARKJOBFINISHEDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllJobInfo',
    full_name='ray.rpc.JobInfoGcsService.GetAllJobInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLJOBINFOREQUEST,
    output_type=_GETALLJOBINFOREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBINFOGCSSERVICE)

DESCRIPTOR.services_by_name['JobInfoGcsService'] = _JOBINFOGCSSERVICE


_ACTORINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='ActorInfoGcsService',
  full_name='ray.rpc.ActorInfoGcsService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=7960,
  serialized_end=8547,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterActor',
    full_name='ray.rpc.ActorInfoGcsService.RegisterActor',
    index=0,
    containing_service=None,
    input_type=_REGISTERACTORREQUEST,
    output_type=_REGISTERACTORREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateActor',
    full_name='ray.rpc.ActorInfoGcsService.CreateActor',
    index=1,
    containing_service=None,
    input_type=_CREATEACTORREQUEST,
    output_type=_CREATEACTORREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetActorInfo',
    index=2,
    containing_service=None,
    input_type=_GETACTORINFOREQUEST,
    output_type=_GETACTORINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNamedActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetNamedActorInfo',
    index=3,
    containing_service=None,
    input_type=_GETNAMEDACTORINFOREQUEST,
    output_type=_GETNAMEDACTORINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetAllActorInfo',
    index=4,
    containing_service=None,
    input_type=_GETALLACTORINFOREQUEST,
    output_type=_GETALLACTORINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.RegisterActorInfo',
    index=5,
    containing_service=None,
    input_type=_REGISTERACTORINFOREQUEST,
    output_type=_REGISTERACTORINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.UpdateActorInfo',
    index=6,
    containing_service=None,
    input_type=_UPDATEACTORINFOREQUEST,
    output_type=_UPDATEACTORINFOREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTORINFOGCSSERVICE)

DESCRIPTOR.services_by_name['ActorInfoGcsService'] = _ACTORINFOGCSSERVICE


_NODEINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='NodeInfoGcsService',
  full_name='ray.rpc.NodeInfoGcsService',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=8550,
  serialized_end=9688,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterNode',
    full_name='ray.rpc.NodeInfoGcsService.RegisterNode',
    index=0,
    containing_service=None,
    input_type=_REGISTERNODEREQUEST,
    output_type=_REGISTERNODEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterNode',
    full_name='ray.rpc.NodeInfoGcsService.UnregisterNode',
    index=1,
    containing_service=None,
    input_type=_UNREGISTERNODEREQUEST,
    output_type=_UNREGISTERNODEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllNodeInfo',
    full_name='ray.rpc.NodeInfoGcsService.GetAllNodeInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLNODEINFOREQUEST,
    output_type=_GETALLNODEINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReportHeartbeat',
    full_name='ray.rpc.NodeInfoGcsService.ReportHeartbeat',
    index=3,
    containing_service=None,
    input_type=_REPORTHEARTBEATREQUEST,
    output_type=_REPORTHEARTBEATREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllHeartbeat',
    full_name='ray.rpc.NodeInfoGcsService.GetAllHeartbeat',
    index=4,
    containing_service=None,
    input_type=_GETALLHEARTBEATREQUEST,
    output_type=_GETALLHEARTBEATREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReportResourceUsage',
    full_name='ray.rpc.NodeInfoGcsService.ReportResourceUsage',
    index=5,
    containing_service=None,
    input_type=_REPORTRESOURCEUSAGEREQUEST,
    output_type=_REPORTRESOURCEUSAGEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllResourceUsage',
    full_name='ray.rpc.NodeInfoGcsService.GetAllResourceUsage',
    index=6,
    containing_service=None,
    input_type=_GETALLRESOURCEUSAGEREQUEST,
    output_type=_GETALLRESOURCEUSAGEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetResources',
    full_name='ray.rpc.NodeInfoGcsService.GetResources',
    index=7,
    containing_service=None,
    input_type=_GETRESOURCESREQUEST,
    output_type=_GETRESOURCESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateResources',
    full_name='ray.rpc.NodeInfoGcsService.UpdateResources',
    index=8,
    containing_service=None,
    input_type=_UPDATERESOURCESREQUEST,
    output_type=_UPDATERESOURCESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteResources',
    full_name='ray.rpc.NodeInfoGcsService.DeleteResources',
    index=9,
    containing_service=None,
    input_type=_DELETERESOURCESREQUEST,
    output_type=_DELETERESOURCESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetInternalConfig',
    full_name='ray.rpc.NodeInfoGcsService.SetInternalConfig',
    index=10,
    containing_service=None,
    input_type=_SETINTERNALCONFIGREQUEST,
    output_type=_SETINTERNALCONFIGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetInternalConfig',
    full_name='ray.rpc.NodeInfoGcsService.GetInternalConfig',
    index=11,
    containing_service=None,
    input_type=_GETINTERNALCONFIGREQUEST,
    output_type=_GETINTERNALCONFIGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllAvailableResources',
    full_name='ray.rpc.NodeInfoGcsService.GetAllAvailableResources',
    index=12,
    containing_service=None,
    input_type=_GETALLAVAILABLERESOURCESREQUEST,
    output_type=_GETALLAVAILABLERESOURCESREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODEINFOGCSSERVICE)

DESCRIPTOR.services_by_name['NodeInfoGcsService'] = _NODEINFOGCSSERVICE


_OBJECTINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='ObjectInfoGcsService',
  full_name='ray.rpc.ObjectInfoGcsService',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  serialized_start=9691,
  serialized_end=10093,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetObjectLocations',
    full_name='ray.rpc.ObjectInfoGcsService.GetObjectLocations',
    index=0,
    containing_service=None,
    input_type=_GETOBJECTLOCATIONSREQUEST,
    output_type=_GETOBJECTLOCATIONSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllObjectLocations',
    full_name='ray.rpc.ObjectInfoGcsService.GetAllObjectLocations',
    index=1,
    containing_service=None,
    input_type=_GETALLOBJECTLOCATIONSREQUEST,
    output_type=_GETALLOBJECTLOCATIONSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddObjectLocation',
    full_name='ray.rpc.ObjectInfoGcsService.AddObjectLocation',
    index=2,
    containing_service=None,
    input_type=_ADDOBJECTLOCATIONREQUEST,
    output_type=_ADDOBJECTLOCATIONREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveObjectLocation',
    full_name='ray.rpc.ObjectInfoGcsService.RemoveObjectLocation',
    index=3,
    containing_service=None,
    input_type=_REMOVEOBJECTLOCATIONREQUEST,
    output_type=_REMOVEOBJECTLOCATIONREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTINFOGCSSERVICE)

DESCRIPTOR.services_by_name['ObjectInfoGcsService'] = _OBJECTINFOGCSSERVICE


_TASKINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='TaskInfoGcsService',
  full_name='ray.rpc.TaskInfoGcsService',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  serialized_start=10096,
  serialized_end=10566,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddTask',
    full_name='ray.rpc.TaskInfoGcsService.AddTask',
    index=0,
    containing_service=None,
    input_type=_ADDTASKREQUEST,
    output_type=_ADDTASKREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='ray.rpc.TaskInfoGcsService.GetTask',
    index=1,
    containing_service=None,
    input_type=_GETTASKREQUEST,
    output_type=_GETTASKREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTasks',
    full_name='ray.rpc.TaskInfoGcsService.DeleteTasks',
    index=2,
    containing_service=None,
    input_type=_DELETETASKSREQUEST,
    output_type=_DELETETASKSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddTaskLease',
    full_name='ray.rpc.TaskInfoGcsService.AddTaskLease',
    index=3,
    containing_service=None,
    input_type=_ADDTASKLEASEREQUEST,
    output_type=_ADDTASKLEASEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTaskLease',
    full_name='ray.rpc.TaskInfoGcsService.GetTaskLease',
    index=4,
    containing_service=None,
    input_type=_GETTASKLEASEREQUEST,
    output_type=_GETTASKLEASEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AttemptTaskReconstruction',
    full_name='ray.rpc.TaskInfoGcsService.AttemptTaskReconstruction',
    index=5,
    containing_service=None,
    input_type=_ATTEMPTTASKRECONSTRUCTIONREQUEST,
    output_type=_ATTEMPTTASKRECONSTRUCTIONREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TASKINFOGCSSERVICE)

DESCRIPTOR.services_by_name['TaskInfoGcsService'] = _TASKINFOGCSSERVICE


_STATSGCSSERVICE = _descriptor.ServiceDescriptor(
  name='StatsGcsService',
  full_name='ray.rpc.StatsGcsService',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  serialized_start=10569,
  serialized_end=10755,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddProfileData',
    full_name='ray.rpc.StatsGcsService.AddProfileData',
    index=0,
    containing_service=None,
    input_type=_ADDPROFILEDATAREQUEST,
    output_type=_ADDPROFILEDATAREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllProfileInfo',
    full_name='ray.rpc.StatsGcsService.GetAllProfileInfo',
    index=1,
    containing_service=None,
    input_type=_GETALLPROFILEINFOREQUEST,
    output_type=_GETALLPROFILEINFOREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATSGCSSERVICE)

DESCRIPTOR.services_by_name['StatsGcsService'] = _STATSGCSSERVICE


_WORKERINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='WorkerInfoGcsService',
  full_name='ray.rpc.WorkerInfoGcsService',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  serialized_start=10758,
  serialized_end=11115,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportWorkerFailure',
    full_name='ray.rpc.WorkerInfoGcsService.ReportWorkerFailure',
    index=0,
    containing_service=None,
    input_type=_REPORTWORKERFAILUREREQUEST,
    output_type=_REPORTWORKERFAILUREREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.GetWorkerInfo',
    index=1,
    containing_service=None,
    input_type=_GETWORKERINFOREQUEST,
    output_type=_GETWORKERINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.GetAllWorkerInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLWORKERINFOREQUEST,
    output_type=_GETALLWORKERINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.AddWorkerInfo',
    index=3,
    containing_service=None,
    input_type=_ADDWORKERINFOREQUEST,
    output_type=_ADDWORKERINFOREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKERINFOGCSSERVICE)

DESCRIPTOR.services_by_name['WorkerInfoGcsService'] = _WORKERINFOGCSSERVICE


_PLACEMENTGROUPINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='PlacementGroupInfoGcsService',
  full_name='ray.rpc.PlacementGroupInfoGcsService',
  file=DESCRIPTOR,
  index=7,
  serialized_options=None,
  serialized_start=11118,
  serialized_end=11653,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreatePlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.CreatePlacementGroup',
    index=0,
    containing_service=None,
    input_type=_CREATEPLACEMENTGROUPREQUEST,
    output_type=_CREATEPLACEMENTGROUPREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.RemovePlacementGroup',
    index=1,
    containing_service=None,
    input_type=_REMOVEPLACEMENTGROUPREQUEST,
    output_type=_REMOVEPLACEMENTGROUPREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.GetPlacementGroup',
    index=2,
    containing_service=None,
    input_type=_GETPLACEMENTGROUPREQUEST,
    output_type=_GETPLACEMENTGROUPREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllPlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.GetAllPlacementGroup',
    index=3,
    containing_service=None,
    input_type=_GETALLPLACEMENTGROUPREQUEST,
    output_type=_GETALLPLACEMENTGROUPREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WaitPlacementGroupUntilReady',
    full_name='ray.rpc.PlacementGroupInfoGcsService.WaitPlacementGroupUntilReady',
    index=4,
    containing_service=None,
    input_type=_WAITPLACEMENTGROUPUNTILREADYREQUEST,
    output_type=_WAITPLACEMENTGROUPUNTILREADYREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLACEMENTGROUPINFOGCSSERVICE)

DESCRIPTOR.services_by_name['PlacementGroupInfoGcsService'] = _PLACEMENTGROUPINFOGCSSERVICE

# @@protoc_insertion_point(module_scope)
